<?php

namespace App\Http\Controllers\Backend\Payments\Razorpay;

use App\Http\Controllers\Backend\Payments\PaymentsController;
use App\Http\Controllers\Controller;

use Illuminate\Http\Request;
use Razorpay\Api\Api;
use App\Models\Order;

class RazorpayController extends Controller
{

    # init payment
    public function initPayment()
    {   
        if (auth()->check()) {
            $user = auth()->user();
            $name=$user->name;
            $email=$user->email;
            $phone=$user->phone;
        }
        else{
            $name=session('user_name');
            $email=session('user_email');
            $phone=session('user_phone');
        }

        $payment_type = session('payment_type');
        
        switch ($payment_type) {
            case 'order_payment':
                $title = localize('Order Payment');
                $orderGroup = Order::where('order_code', session('order_code'))->first();
                $amount = $orderGroup->grand_total_amount ?? 0;
                break;
            default:
                $title = '';
                $amount = 0;
        }
 
        if ($amount <= 0) {
            return (new PaymentsController)->payment_failed();
        }

        $data = [
            'amount' => $amount * 100,
            'name' => $name,
            'email' => $email,
            'phone' => $phone,
            'app_name' => env('APP_NAME'),
            'app_logo' => uploadedAsset(getSetting('navbar_logo')),
            'payment_title' => $title
        ];
        return view('payments.razorpay', compact('data'));
    }


    # make payment
    public function payment(Request $request)
    {
        //Input items of form
        $input = $request->all();
      
        //get API Configuration
        $api = new Api(env('RAZORPAY_KEY'), env('RAZORPAY_SECRET'));
    

        //Fetch payment information by razorpay_payment_id
        $payment = $api->payment->fetch($input['razorpay_payment_id']);

        if (count($input)  && !empty($input['razorpay_payment_id'])) {
            $payment_details = null;
            try {

                $response = $api->payment->fetch($input['razorpay_payment_id'])->capture(array('amount' => $payment['amount']));
                $payment_details = json_encode(array(
                    'id' => $response['id'],
                    'method' => $response['method'],
                    'amount' => $response['amount'],
                    'currency' => $response['currency']
                ));
            } catch (\Exception $e) {
                return (new PaymentsController)->payment_failed();
            }

            if (session('payment_type') == 'order_payment') {
                return (new PaymentsController)->payment_success(json_encode($payment_details));
            }
        }
    }
}
