<?php

namespace App\Http\Controllers\Backend\Products;

use App\Http\Controllers\Controller;
use App\Models\ProductTax;
use App\Models\ProductReview;
use App\Models\Product;
use Illuminate\Http\Request;
use Auth;

class ReviewController extends Controller
{
    # construct
    public function __construct()
    {
        $this->middleware(['permission:taxes'])->only('index');
        $this->middleware(['permission:add_taxes'])->only(['store']);
        $this->middleware(['permission:edit_taxes'])->only(['edit', 'update']);
        $this->middleware(['permission:publish_taxes'])->only(['updateStatus']);
        $this->middleware(['permission:delete_taxes'])->only(['delete']);
    }

    # tax list
    public function index(Request $request)
    {
        $reviewList = ProductReview::all();
        $productlist = Product::all();
        return view('backend.pages.products.review.index',compact('reviewList','productlist'));
    }

    # tax store
    public function store(Request $request)
    {
        $review = new ProductReview();
        $review->product_id = $request->product;
        $review->user_id = Auth::user()->id ?? null;
        $review->rating = $request->rating;
        $review->review_text = $request->review_text;
        $review->status = 1;
        $review->save();

        flash(localize('Review has been inserted successfully'))->success();
        return redirect()->route('admin.review.index');
    }

    # edit tax
    public function edit($id)
    {
        $Review = ProductReview::findOrFail($id);
        $productlist = Product::all();
        return view('backend.pages.products.review.edit', compact('Review','productlist'));
    }

    # update tax
    public function update(Request $request)
    {
        $review = ProductReview::findOrFail($request->id);
        $review->product_id = $request->product;
        $review->user_id = Auth::user()->id ?? null;
        $review->rating = $request->rating;
        $review->review_text = $request->review_text;
        $review->status = 1;
        $review->save();

        flash(localize('Review has been updated successfully'))->success();
        return back();
    }

    

    # delete tax
    public function delete($id)
    {
        $review = ProductReview::findOrFail($id); 
        $review->delete();
        flash(localize('Review has been deleted successfully'))->success();
        return back();
    }
}
