<?php

namespace App\Http\Controllers\Frontend;

use App\Http\Controllers\Controller;
use App\Http\Resources\ProductVariationInfoResource;
use App\Models\Category;
use App\Models\Product;
use App\Models\ProductCategory;
use App\Models\ProductTag;
use App\Models\ProductVariation;
use App\Models\Tag;
use App\Models\Variation;
use App\Models\VariationValue;
use App\Models\Brand;
use App\Models\ProductVariationCombination;
use Illuminate\Http\Request;

class CategoryController extends Controller
{
    # product listing

    public function show(Request $request,$slug)
    {   
        $searchKey = null;
        $per_page = 9;
        $sort_by = $request->sort_by ? $request->sort_by : "new";
        $maxRange = Product::max('max_price');
        $min_value = 0;
        $max_value = formatPrice($maxRange, false, false, false, false);

        $category = Category::where('slug', $slug)->first();

        if (empty($category)) {
            flash(localize('This category is not available'))->info();
            return redirect()->route('home');
        } else {

            $products = Product::isPublished();

            $product_category_product_ids = ProductCategory::where('category_id', $category->id)->pluck('product_id');
            $products = $products->whereIn('id', $product_category_product_ids);

            $productObj = $products;

            $tempAttrArray = $attriButeArray = [];

            foreach ($productObj->get() as $productData) {
                $variationIds = ProductVariationCombination::where('product_id', $productData->id)->pluck('variation_id')->toArray();
                $tempAttrArray = array_merge($tempAttrArray, $variationIds);
            }

            // To get unique variation IDs, you can use array_unique
            $tempAttrArray = array_unique($tempAttrArray);

            if (sizeof($tempAttrArray) > 0) {

                foreach ($tempAttrArray as $key => $value) {

                    $variationName = Variation::where('id', $value)->first();
                    $variationValue = VariationValue::where('variation_id', $value)->get();

                    $attriButeArray[$variationName->name] = $variationValue;
                }
            }


            # conditional - search by
            if ($request->search != null) {
                $products = $products->where('name', 'like', '%' . $request->search . '%');
                $searchKey = $request->search;
            }

            # pagination
            if ($request->per_page != null) {
                $per_page = $request->per_page;
            }

            # sort by
            if ($sort_by == 'new') {
                $products = $products->latest();
            }
            if ($sort_by == 'best_selling') {
                $products = $products->orderBy('total_sale_count', 'DESC');
            }

            if ($sort_by == 'atoz' || $sort_by == 'ztoa') {

                $products = $products->orderBy('slug', $sort_by == 'atoz' ? 'ASC' : 'DESC');
            }

            if ($sort_by == 'pricemintohigh' || $sort_by == 'pricehightomin') {

                $products = $products->orderBy('min_price', ($sort_by == 'pricemintohigh') ? 'ASC' : 'DESC');
            }
        }

        # by price
        if ($request->min_price != null) {
            $min_value = $request->min_price;
        }
        if ($request->max_price != null) {
            $max_value = $request->max_price;
        }

        if ($request->min_price || $request->max_price) {
            $products = $products->where('min_price', '>=', priceToUsd($min_value))->where('min_price', '<=', priceToUsd($max_value));
        }

        # by category
        if ($request->category_id && $request->category_id != null) {
            $product_category_product_ids = ProductCategory::where('category_id', $request->category_id)->pluck('product_id');
            $products = $products->whereIn('id', $product_category_product_ids);
        }

        # by tag
        if ($request->tag_id && $request->tag_id != null) {
            $product_tag_product_ids = ProductTag::where('tag_id', $request->tag_id)->pluck('product_id');
            $products = $products->whereIn('id', $product_tag_product_ids);
        }
        # conditional




        if (!empty($request) && !empty($request->attribute)) {


            $productIdsArray = $productIds = [];

            foreach ($request->attribute as $attrValue) {

                $temVals = explode('_', $attrValue);

                $varCombData = ProductVariationCombination::where(['variation_value_id' => $temVals[0], 'variation_id' => $temVals[1]])->pluck('product_id')->toArray();
                $productIdsArray = $varCombData;
            }

            // dd($productIdsArray);

            foreach ($productObj->get() as $product) {

                if (in_array($product->id, $productIdsArray)) {

                    $productIds[] = $product->id;
                }
            }

            $products = $products->whereIn('id', $productIds);
        }


        $products = $products->paginate(paginationNumber($per_page));
        // $products = $products->paginate(1);

        $tags = Tag::all();

        // $cateArray = array();

        // $cat = Category::where('parent_id', $category->id)->get();

        // foreach ($cat as $pcate) {
        //     $cateArray[] = $pcate;
        //     $subcate = Category::where('parent_id', $pcate->categories_id)->get();
        //     foreach ($subcate as $ccate)
        //         $cateArray[] = $ccate->categories_id;
        // }
        $cateArray = Category::all();


        return getView('pages.product_listing', [
            'products'      => $products,
            'searchKey'     => $searchKey,
            'per_page'      => $per_page,
            'sort_by'       => $sort_by,
            'max_range'     => formatPrice($maxRange, false, false, false, false),
            'min_value'     => $min_value,
            'max_value'     => $max_value,
            'tags'          => $tags,
            'category'      => $category,
            'cateArray'     => $cateArray,
            'attriButeArray' => $attriButeArray,
            'selectedAttr'  => $request->attribute ?? [],
        ]);
      
    }

}
