<?php

namespace App\Http\Controllers\Frontend;

use App\Http\Controllers\Backend\Payments\PaymentsController;
use App\Http\Controllers\Controller;
use App\Http\Requests\OrderAddress;
use App\Models\Cart;
use App\Models\Country;
use Auth;
use App\Models\Order;
use App\Models\OrderItem;
use Illuminate\Validation\ValidationException;
use App\Notifications\OrderPlacedNotification;
use Illuminate\Http\Request;
use Notification;
use Config;
use Session;
use App\Models\AddOnProduct;
use App\Models\Language;
use App\Models\User;
use App\Models\UserAddress;
use Illuminate\Support\Facades\Hash;
use PDF;
use App\Http\Services\SmsServices;
use App\Models\OrderUpdate;
use App\Models\OrderGroup;
use App\Models\State;
use Illuminate\Support\Facades\Validator;



class CheckoutController extends Controller
{
    # checkout
    public function index(Request $request)
    {   
        if (Auth::check()) {
            $carts = Cart::where('user_id', Auth::user()->id)->get();
        } else {
            $carts = Cart::where(['guest_id' => (int) $_COOKIE['guest_user_id']])->get();
        }

        $countries = Country::isActive()->get();
        $states = State::isActive()->where('country_id',101)->get();

        $userObj='';
        
        if (auth()->check()) {

            $userObj = User::with(['addresses' => function ($query) {
                $query->orderBy('id','DESC')->take(6);
            }])->where('id', auth()->user()->id)->first();
        }
    
        return getView('pages.checkout', [
            'carts'     => $carts,
            'countries' => $countries,
            'states' => $states,
            'userObj' => $userObj,
        ]);
    }

   
    # complete checkout process
    public function complete(OrderAddress $request)
    {       
    //    dd($request->all());

        if (Auth::check()) {
            $carts = Cart::where('user_id', Auth::user()->id)->get();
        } else {
            $carts = Cart::where(['guest_id' => (int) $_COOKIE['guest_user_id']])->get();
        }
      
        if (count($carts) > 0) {

            if (auth()->check()) {

                $userId = auth()->user()->id;

            }else{

                $userObj = User::where(['phone' => $request->billing_customer_phone])->first();

                if (empty($userObj)) {

                    $randPassword=rand(100000,500000);

                    $user=User::create([
                        'user_type'=>'customer',
                        'name'=>$request->billing_customer_name,
                        'email'=>strtolower($request->billing_customer_email ?? ''),
                        'phone'=>$request->billing_customer_phone,
                        'password'=>Hash::make($randPassword),
                    ]);

                
                    if(!empty($request->billing_customer_phone)){

                            // Send Mail Notification to user
                            $message="";
                            $message.="Welcome to KhemchandJewellers.com\n";
                            $message.="Your Login Details are - \n";
                            if(!empty($request->billing_customer_phone))
                            $message.="Phone Number : ".$request->billing_customer_phone."\n";
                            if(!empty($request->billing_customer_email))
                            $message.="Email : ".$request->billing_customer_email."\n";
                            $message.="Password : ".$randPassword."\n";
                            $message.="Thank You";

                            $details['receiver_data'] = $user;
                            $details['content'] = $message; 
                            $details['source'] = "phone"; 

                        try {
                            $job = (new \App\Jobs\SendQueueEmail($details))->delay(now()->addSeconds(2)); 
                            dispatch($job);
                            
                        } catch (\Exception $e) {
                            // dd($e->getMessage());
                        }
                    }


                    if(!empty($request->billing_customer_email)){

                        try {
                            $user->generatedpassword=$randPassword;
                            $details['receiver_data'] = $user;
                            $details['view'] = 'emails.guest_register_mail';
                            $details['subject'] = "Welcome to khemchandjewellers.com";
                            $details['from'] = env('MAIL_FROM_ADDRESS');
                            $details['source'] = "email"; 

                            $job = (new \App\Jobs\SendQueueEmail($details))->delay(now()->addSeconds(2)); 

                            dispatch($job);

                        } catch (\Exception $e) {
                        //    dd($e->getMessage());
                        }
                    }

                } else{

                    $user=$userObj;
                }

                session(['user_name' => $user->name ,'user_email'=>$user->email,'user_phone'=>$user->phone]);

                $userId = $user->id;
            } 

         
            $finalAmount = $request->finalAmount;
            $shipping_total = $request->delivery_charge;
           
            
            # create new order 
            $Order                                     = new Order;
            $Order->user_id                            = $userId;
            $Order->sub_total_amount                   = getSubTotal($carts, false, '', false);
            $Order->total_tax_amount                   = getTotalTax($carts);
            $Order->grand_total_amount                 = getTotalTax($carts) + $finalAmount;
            $Order->payment_method                     = $request->payment_method;
            $Order->delivery_type                      = $request->deliveryType ?? 1;
            $Order->order_note                         = $request->order_note;
            $Order->shipping_total                     = $shipping_total;
            $Order->save();

            
            # Store Customer Address

            UserAddress::where('user_id',$userId)->update(['is_default' => 0]);
        
            if(empty($request->address_id)) {  

                # Store Customer Address
                $bill_address                = new UserAddress;
                $bill_address->user_id       = $userId;
                $bill_address->order_id      = $Order->order_id;
                $bill_address->name          = $request->billing_customer_name ?? '';
                $bill_address->country_id  = $request->billing_customer_country ?? '';
                $bill_address->state         = $request->billing_customer_state ?? '';
                $bill_address->city          = $request->billing_customer_city ?? '';
                $bill_address->address       = $request->billing_customer_address ?? '';
                $bill_address->phone         = $request->billing_customer_phone;
                $bill_address->pincode       = $request->billing_customer_postcode ?? '';
                $bill_address->address_type  = 1;
                $bill_address->save();

                if ($request->has('is_shipping_diff')) {  // if bill shipp diff
                    
                    $ship_address                = new UserAddress;
                    $ship_address->user_id       = $userId;
                    $ship_address->order_id      = $Order->order_id;
                    $ship_address->name          = $request->shipping_customer_name ?? '';
                    $ship_address->country_id  = $request->shipping_customer_country ?? '';
                    $ship_address->state         = $request->shipping_customer_state ?? '';
                    $ship_address->city          = $request->shipping_customer_city ?? '';
                    $ship_address->address       = $request->shipping_customer_address ?? '';
                    $ship_address->phone         = $request->shipping_customer_phone;
                    $ship_address->pincode       = $request->shipping_customer_postcode ?? '';
                    $ship_address->address_type  = 2;
                    $ship_address->is_default    = 1;
                    $ship_address->save();

                } else {  

                    // create replica of billing if same
                    $shipping = $bill_address->replicate()->fill(['address_type' => 2,'is_default'=>1]);
                    $shipping->save();
                }
            }
            else{

                $CustAdd=UserAddress::find($request->address_id);
                
                if(!empty($CustAdd))
                { 

                $address=[];

                 $address=[
                    'name'=>$CustAdd->name,'country_id'=>$CustAdd->country_id,
                    'address'=>$CustAdd->address,
                    'city'=>$CustAdd->city, 'state'=>$CustAdd->state,
                    'pincode'=>$CustAdd->pincode, 'phone'=>$CustAdd->phone,
                    'order_id'=>$Order->order_id , 'address_type'=>1,'user_id'=>$userId
                   ];
       
                   $bill_address = UserAddress::create($address);

                    if ($request->has('is_shipping_diff')) {  // if bill shipp diff
                    
                        $ship_address                = new UserAddress;
                        $ship_address->user_id       = $userId;
                        $ship_address->order_id      = $Order->order_id;
                        $ship_address->name          = $request->shipping_customer_name ?? '';
                        $ship_address->country_id  = $request->shipping_customer_country ?? '';
                        $ship_address->state         = $request->shipping_customer_state ?? '';
                        $ship_address->city          = $request->shipping_customer_city ?? '';
                        $ship_address->address       = $request->shipping_customer_address ?? '';
                        $ship_address->phone         = $request->shipping_customer_phone;
                        $ship_address->pincode       = $request->shipping_customer_postcode ?? '';
                        $ship_address->address_type  = 2;
                        $ship_address->is_default    = 1;
                        $ship_address->save();

                    } else {  

                        // create replica of billing if same
                        $shipping = $bill_address->replicate()->fill(['address_type' => 2,'is_default'=>1]);
                        $shipping->save();
                    }

                }
                else
                {        
                   $Order->delete();
                   return redirect('/');  // Any changes in address id redirect to home page
                }
            }


            $Order->phone_no  = $bill_address->phone;
            $Order->address_id  = $bill_address->id;
            $Order->save();


            # order items
            $total_points = 0;
            foreach ($carts as $cart) {

                $orderItem                       = new OrderItem;
                $orderItem->order_id             = $Order->order_id;
                $orderItem->product_id           = $cart->product_id;
                $orderItem->product_name         = $cart->product_variation->product->collectLocalization('name');
                $orderItem->product_type         = 1;
                $orderItem->product_variation_id = $cart->product_variation_id;
                // $orderItem->product_variation    = $cart->product_variation->code;
                // $orderItem->order_attributes     = $cart->attributes;
                $orderItem->qty                  = $cart->qty;
                $orderItem->order_message        = $cart->message;
                $orderItem->unit_price           = variationDiscountedPrice($cart->product_variation->product, $cart->product_variation);
                $orderItem->total_tax            = variationTaxAmount($cart->product_variation->product, $cart->product_variation);
                $orderItem->total_price          = $orderItem->unit_price * $orderItem->qty;    
                $orderItem->save();

                 // Update For Main Product

                 $product = $cart->product_variation->product;
                 $product->total_sale_count += $cart->qty;
                 $product->save();

                 $cart->delete();
            }

            $order = Order::where('order_code', $Order->order_code)->first();

         
            # payment gateway integration & redirection

            $Order->payment_method = $request->payment_method;
            $Order->save();


            if ($request->payment_method != "cod") {

                $request->session()->put('payment_type', 'order_payment');
                $request->session()->put('order_code', $Order->order_code);
                $request->session()->put('payment_method', $request->payment_method);

                # init payment
                $payment = new PaymentsController;
                
                return $payment->initPayment();

            } else {
             
                if(empty($request->parse_payment) && $request->parse_payment!="part_payment")

                
                $request->session()->put('payment_type', 'order_payment');
                $request->session()->put('order_code', $Order->order_code);
                $request->session()->put('payment_method', $request->payment_method);

                
                $Order->payment_status = 1;

                $Order->order_status = 5;
                $Order->save();
 
                $encodedData = base64_encode($order->order_code);

                return redirect()->route('checkout.success', $encodedData)->with('success' , 'Your order has been placed successfully');

            }
        }

        flash(localize('Your cart is empty'))->error();
        return redirect()->route('home');
    }

    # order successful
    public function success($code)
    {   
        $decodedData = base64_decode($code);

        $order = Order::where('order_code', $decodedData)->first();
       
        if(empty($order))
            return redirect()->route('home');
        // todo:: change this from here

        try {

            $user=$order->user()->first();
            
            OrderUpdate::create([
                'order_id' => $order->order_id,
                'note' => 'Order Created.',
            ]);
        
           // Send Notification

           $admin_message="";
           $admin_message.="New Order Received In KhemchandJewellers.com\n";
           $admin_message.="Thank You";

           $user_message="";
           $user_message.="Your order placed successfully in KhemchandJewellers.com\n";
           $user_message.="Thank You";

           SmsServices::SendSMS(getSetting('order_contact_number'),$admin_message); #To Admin
           SmsServices::SendSMS($order->phone_no,$user_message); #To Customer


            if(!empty($user->email)){

                try {

                    $details['receiver_data'] = $user;
                    $details['order_data'] = $order;
                    $details['view'] = 'emails.order_mail';
                    $details['subject'] = 'Order Placed' . ' - ' . env('APP_NAME');
                    $details['from'] = env('MAIL_FROM_ADDRESS');
                    $details['source'] = "email"; 

                    $job = (new \App\Jobs\SendQueueEmail($details))->delay(now()->addSeconds(2)); 

                    dispatch($job);

                } catch (\Exception $e) {
                //    dd($e->getMessage());
                }
            }


        } catch (\Exception $e) {
            // dd($e->getMessage());
        }
    
        return getView('pages.order_thanks', ['order' => $order]);
    }


    # order invoice
    public function invoice($code)
    {   
        if (session()->has('locale')) {
            $language_code = session()->get('locale', Config::get('app.locale'));
        } else {
            $language_code = env('DEFAULT_LANGUAGE') ?? Config::get('app.locale');
        }
   
        if (session()->has('currency_code')) {
            $currency_code = session()->get('currency_code', Config::get('app.currency_code'));
        } else {
            $currency_code = env('DEFAULT_CURRENCY') ?? Config::get('app.currency_code');
        }
       
        if (Language::where('code', $language_code)->first()->is_rtl == 1) {
            $direction = 'rtl';
            $default_text_align = 'right';
            $reverse_text_align = 'left';
        } else {
            $direction = 'ltr';
            $default_text_align = 'left';
            $reverse_text_align = 'right';
        }

        if ($currency_code == 'BDT' || $currency_code == 'bdt' || $language_code == 'bd' || $language_code == 'bn') {
            # bengali font
            $font_family = "'Hind Siliguri','sans-serif'";
        } elseif ($currency_code == 'KHR' || $language_code == 'kh') {
            # khmer font
            $font_family = "'Khmeros','sans-serif'";
        } elseif ($currency_code == 'AMD') {
            # Armenia font
            $font_family = "'arnamu','sans-serif'";
        } elseif ($currency_code == 'AED' || $currency_code == 'EGP' || $language_code == 'sa' || $currency_code == 'IQD' || $language_code == 'ir') {
            # middle east/arabic font
            $font_family = "'XBRiyaz','sans-serif'";
        } else {
            # general for all
            $font_family = "'Roboto','sans-serif'";
        }

        $order = Order::where('order_code',$code)->first();
       
        return PDF::loadView('backend.pages.orders.invoice', [
            'order' => $order,
            'font_family' => $font_family,
            'direction' => $direction,
            'default_text_align' => $default_text_align,
            'reverse_text_align' => $reverse_text_align
        ], [], [])->download(getSetting('order_code_prefix') . $order->order_code . '.pdf');
    }

    # update payment status
    public function updatePayments($payment_details)
    {
        $orderGroup = Order::where('order_code', session('order_code'))->first();
        $payment_method = session('payment_method');

        $orderGroup->payment_status = paidPaymentStatus();
        // $orderGroup->order->update(['payment_status' => paidPaymentStatus()]); # for multi-vendor loop through each orders & update

        $orderGroup->payment_method = $payment_method;
        $orderGroup->payment_details = $payment_details;
        $orderGroup->save();

        clearOrderSession();
        flash(localize('Your order has been placed successfully'))->success();

        $encodedData = base64_encode($orderGroup->order_code);

        return redirect()->route('checkout.success', $encodedData);
    }
}
