<?php

namespace App\Http\Controllers\Frontend;

use App\Http\Controllers\Controller;

use Illuminate\Http\Request;
use App\Models\Category;
use App\Models\Product;
use App\Models\ProductReview;
use App\Models\Page;
use Auth;


class HomeController extends Controller
{
    # set theme
    public function theme($name = "")
    {
        session(['theme' => $name]);
        return redirect()->route('home');
    }


    # homepage
    public function index()
    {   
        $sliders = [];
        if (getSetting('hero_sliders') != null) {
            $sliders = json_decode(getSetting('hero_sliders'));
        }

        $top_category_ids = getSetting('top_category_ids') != null ? json_decode(getSetting('top_category_ids')) : [];
        $categories = Category::whereIn('id', $top_category_ids)->get();

        $featured_products = getSetting('featured_products') != null ? json_decode(getSetting('featured_products')) : [];
        $featureProducts = Product::whereIn('id', $featured_products)->get();

        // $giveaway_products = getSetting('giveaway_products') != null ? json_decode(getSetting('giveaway_products')) : [];


        $giveawayProducts = Product::where(['is_published'=>1,'giveaway_product'=>1])->get();
 

        $trending_products = getSetting('top_trending_products') != null ? json_decode(getSetting('top_trending_products')) : [];
        $trendingProducts = Product::whereIn('id', $trending_products)->get();

        $recent_added_products = getSetting('recent_added_products') != null ? json_decode(getSetting('recent_added_products')) : [];
        $recentProducts = Product::whereIn('id', $recent_added_products)->orderBy('created_at','DESC')->limit(3)->get();

        $banner_section_one_banners = [];
        if (getSetting('banner_section_one_banners') != null) {
            $banner_section_one_banners = json_decode(getSetting('banner_section_one_banners'));
        }

        $client_feedback = [];
        if (getSetting('client_feedback') != null) {
            $client_feedback = json_decode(getSetting('client_feedback'));
        }

        
        return getView('pages.home', ['recentProducts'=>$recentProducts,'featureProducts'=>$featureProducts,'trendingProducts'=>$trendingProducts,'categories'=>$categories, 'sliders' => $sliders,'banner_section_one_banners' => $banner_section_one_banners , 'client_feedback' => $client_feedback,'giveawayProducts' => $giveawayProducts]);
    }

   

    # all categories
    public function allCategories()
    {
        return getView('pages.categories');
    }


    # contact us page
    public function contactUs()
    {  
         return view('frontend.pages.contactUs');
    }

    public function review(Request $request){


        if(auth()->user()->user_type == 'customer'){

            $review = new ProductReview();
            $review->product_id = $request->product_id;
            $review->user_id = Auth::user()->id ?? null;
            $review->rating = $request->rating;
            $review->review_text = $request->review_text;
            $review->status = 1;
            $review->save();

            return redirect()->back();
        }else{
            flash(localize('Please Login As Customer'))->error();
            return back();
        }
    }

     # about us page
     public function aboutUs()
     {
        $features = [];

        if (getSetting('about_us_features') != null) {
            $features = json_decode(getSetting('about_us_features'));
        }

        $why_choose_us = [];

        if (getSetting('about_us_why_choose_us') != null) {
            $why_choose_us = json_decode(getSetting('about_us_why_choose_us'));
        }
 
         return view('frontend.pages.aboutUs', ['features' => $features, 'why_choose_us' => $why_choose_us]);
     }

     # quick link / dynamic pages
    public function showPage($slug)
    {
        $page = Page::where('slug', $slug)->first();
        return view('frontend.default.pages.quickLinks.index', ['page' => $page]);
    }
 
  
}
