<?php
  
namespace App\Http\Requests;
  
use Illuminate\Foundation\Http\FormRequest;
  
class OrderAddress extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }
  
    /** 
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {   
        return [
            //Billing

            'billing_customer_name'=>'sometimes|required|string',
            'billing_customer_phone'=>'sometimes|required',
            'billing_customer_email'=>'sometimes|nullable|email|regex:/(.+)@(.+)\.(.+)/i',
            'billing_customer_address'=>'sometimes|required',
            'billing_customer_city'=>'sometimes|required',
            'billing_customer_state'=>'sometimes|required',
            'billing_customer_country'=>'sometimes|required',
            'billing_customer_postcode'=>'sometimes|required',


            'payment_method'=>'required',
        

            // Shipping

            'shipping_customer_name'=>'exclude_unless:is_shipping_diff,on|required|string',
            'shipping_customer_country'=>'exclude_unless:is_shipping_diff,on|required',
            'shipping_customer_address'=>'exclude_unless:is_shipping_diff,on|required',
            'shipping_customer_city'=>'exclude_unless:is_shipping_diff,on|required',
            'shipping_customer_state'=>'exclude_unless:is_shipping_diff,on|required',
            'shipping_customer_postcode'=>'exclude_unless:is_shipping_diff,on|required',
            'shipping_customer_phone'=>'exclude_unless:is_shipping_diff,on|required',
            'shipping_customer_email'=>'exclude_unless:is_shipping_diff,on|nullable|email|regex:/(.+)@(.+)\.(.+)/i',

            ];
    }

    public function messages() {
      
        return [

                // Billing
            'billing_customer_name.required' => 'The billing customer name is required.',
            'billing_customer_name.string' => 'The billing customer name must be a string.',
            'billing_customer_phone.required' => 'The billing customer phone is required.',
            'billing_customer_email.email' => 'The billing customer email must be a valid email address.',
            'billing_customer_email.regex' => 'The billing customer email format is invalid.',
            'billing_customer_address.required' => 'The billing customer address is required.',
            'billing_customer_city.required' => 'The billing customer city is required.',
            'billing_customer_state.required' => 'The billing customer state is required.',
            'billing_customer_country.required' => 'The billing customer country is required.',
            'billing_customer_postcode.required' => 'The billing customer postcode is required.',

            'payment_method.required' => 'Please select payment mode.',

            // Shipping
            'shipping_customer_name.required' => 'The shipping customer name is required when shipping is different.',
            'shipping_customer_name.string' => 'The shipping customer name must be a string when shipping is different.',
            'shipping_customer_country.required' => 'The shipping customer country is required when shipping is different.',
            'shipping_customer_address.required' => 'The shipping customer address is required when shipping is different.',
            'shipping_customer_city.required' => 'The shipping customer city is required when shipping is different.',
            'shipping_customer_state.required' => 'The shipping customer state is required when shipping is different.',
            'shipping_customer_postcode.required' => 'The shipping customer postcode is required when shipping is different.',
            'shipping_customer_phone.required' => 'The shipping customer phone is required when shipping is different.',
            'shipping_customer_email.email' => 'The shipping customer email must be a valid email address when shipping is different.',
            'shipping_customer_email.regex' => 'The shipping customer email format is invalid when shipping is different.',


        ];
    }

}