<?php

namespace App\Jobs;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldBeUnique;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Mail;
use App\Mail\EmailManager;
use App\Http\Services\SmsServices;


class SendQueueEmail implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

    /**
     * Create a new job instance.
     *
     * @return void
     */
    
    public $data;
    public $timeout = 7200; // 2 hours
    
    public function __construct($data)
    {
        $this->data = $data;
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle() 
    {  
      if($this->data['source']=="email"){

        try{
            Mail::to($this->data['receiver_data']->email)->send(new EmailManager($this->data));
        } catch (Exception $e) {
            Log::info($e->getMessage());
        }

      } else{

        try{
          SmsServices::SendSMS($this->data['receiver_data']->phone,$this->data['content']); #To Customer
        } catch (Exception $e) {
          Log::info($e->getMessage());
        }

      }
    }
    
}
