<x-backend.app-layout>

@section('title')
    {{ localize('Pages') }} {{ getSetting('title_separator') }} {{ getSetting('system_title') }}
@endsection


<section class="tt-section pt-4">
    <div class="container">
        <div class="row mb-3">
            <div class="col-12">
                <div class="card tt-page-header">
                    <div class="card-body d-lg-flex align-items-center justify-content-lg-between">
                        <div class="tt-page-title">
                            <h2 class="h5 mb-lg-0">{{ localize('Pages') }}</h2>
                        </div>
                        <div class="tt-action">
                            @can('add_pages')
                                <a href="{{ route('admin.pages.create') }}" class="btn btn-primary"><i
                                        data-feather="plus"></i> {{ localize('Add Page') }}</a>
                            @endcan
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="row g-4">
            <div class="col-12">
                <div class="card mb-4" id="section-1">
                    <form class="app-search" action="{{ Request::fullUrl() }}" method="GET">
                        <div class="card-header border-bottom-0">
                            <div class="row justify-content-between g-3">
                                <div class="col-auto flex-grow-1">
                                    <div class="tt-search-box">
                                        <div class="input-group">
                                            <span class="position-absolute top-50 start-0 translate-middle-y ms-2"> <i
                                                    data-feather="search"></i></span>
                                            <input class="form-control rounded-start w-100" type="text"
                                                id="search" name="search" placeholder="{{ localize('Search') }}"
                                                @isset($searchKey)
                                                value="{{ $searchKey }}"
                                            @endisset>
                                        </div>
                                    </div>
                                </div>

                                <div class="col-auto">
                                    <button type="submit" class="btn btn-secondary">
                                        <i data-feather="search" width="18"></i>
                                        {{ localize('Search') }}
                                    </button>
                                </div>
                            </div>
                        </div>
                    </form>

                    <table class="table tt-footable border-top" data-use-parent-width="true">
                        <thead>
                            <tr>
                                <th class="text-center">{{ localize('S/L') }}</th>
                                <th>{{ localize('Title') }}</th>
                                <th>{{ localize('Page Link') }}</th>
                                <th data-breakpoints="xs sm" class="text-end">{{ localize('Action') }}
                                </th>
                            </tr>
                        </thead>
                        <tbody>
                            @foreach ($pages as $key => $page)
                                <tr>
                                    <td class="text-center">
                                        {{ $key + 1 + ($pages->currentPage() - 1) * $pages->perPage() }}</td>
                                    <td>
                                        <span class="fw-semibold">
                                            {{ $page->collectLocalization('title') }}
                                        </span>
                                    </td>
                                    <td>
                                        <a href="{{ \Request::root() . '/page/' . $page->slug }}" target="_blank" class="text-dark">{{ \Request::root() . '/page/' . $page->slug }}</a>
                                    </td>

                                    <td class="text-end">
                                        <div class="dropdown tt-tb-dropdown">
                                            <button type="button" class="btn p-0" data-bs-toggle="dropdown"
                                                aria-expanded="false">
                                                <i data-feather="more-vertical"></i>
                                            </button>
                                            <div class="dropdown-menu dropdown-menu-end shadow">

                                                @can('edit_pages')
                                                    <a class="dropdown-item"
                                                        href="{{ route('admin.pages.edit', ['id' => $page->id, 'lang_key' => env('DEFAULT_LANGUAGE')]) }}&localize">
                                                        <i data-feather="edit-3" class="me-2"></i>{{ localize('Edit') }}
                                                    </a>
                                                @endcan

                                                <a class="dropdown-item"
                                                    href="{{ route('home.pages.show', $page->slug) }}" target="_blank">
                                                    <i data-feather="eye" class="me-2"></i>{{ localize('View') }}
                                                </a>

                                                @can('delete_pages')
                                                    <a href="#" class="dropdown-item confirm-delete"
                                                        data-href="{{ route('admin.pages.delete', $page->id) }}"
                                                        title="{{ localize('Delete') }}">
                                                        <i data-feather="trash-2" class="me-2"></i>
                                                        {{ localize('Delete') }}
                                                    </a>
                                                @endcan
                                            </div>
                                        </div>
                                    </td>
                                </tr>
                            @endforeach
                        </tbody>
                    </table>
                    <!--pagination start-->
                    <div class="d-flex align-items-center justify-content-between px-4 pb-4">
                        <span>{{ localize('Showing') }}
                            {{ $pages->firstItem() }}-{{ $pages->lastItem() }} {{ localize('of') }}
                            {{ $pages->total() }} {{ localize('results') }}</span>
                        <nav>
                            {{ $pages->appends(request()->input())->links() }}
                        </nav>
                    </div>
                    <!--pagination end-->
                </div>
            </div>
        </div>
    </div>
</section>

</x-backend.app-layout>