<x-frontend.app-layout>
  @section('title')
    {{ localize('Product Details') }} {{ getSetting('title_separator') }} {{ $product->collectLocalization('name') }}
  @endsection

  @section('meta')
    <!-- Schema.org markup for Google+ -->
    <meta itemprop="name" content="{{ $product->meta_title }}">
    <meta itemprop="description" content="{{ $product->meta_description }}">
    <meta itemprop="image" content="{{ uploadedAsset($product->thumbnail_image) }}">

    <!-- Twitter Card data -->
    <meta name="twitter:card" content="product">
    <meta name="twitter:site" content="@publisher_handle">
    <meta name="twitter:title" content="{{ $product->meta_title }}">
    <meta name="twitter:description" content="{{ $product->meta_description }}">
    <meta name="twitter:creator" content="@author_handle">
    <meta name="twitter:image" content="{{ uploadedAsset($product->thumbnail_image) }}">
    <meta name="twitter:data1" content="{{ formatPrice($product->min_price) }}">
    <meta name="twitter:label1" content="Price">

    <!-- Open Graph data -->
    <meta property="og:title" content="{{ $product->meta_title }}" />
    <meta property="og:type" content="og:product" />
    <meta property="og:url" content="{{ route('products.show', $product->slug) }}" />
    <meta property="og:image" content="{{ uploadedAsset($product->thumbnail_image) }}" />
    <meta property="og:description" content="{{ $product->meta_description }}" />
    <meta property="og:site_name" content="{{ getSetting('meta_title') }}" />
    <meta property="og:price:amount" content="{{ formatPrice($product->min_price) }}" />
    <meta property="product:price:currency" content="{{ env('DEFAULT_CURRENCY') }}" />

@endsection

  @php
      $galleryImages = !empty($product->gallery_images) ? explode(',', $product->gallery_images) : [];
  @endphp 
  
   <main>
         
     <!-- breadcrumb area start -->
    <div class="breadcrumb-area">
        <div class="container">
            <div class="row">
                <div class="col-12">
                    <div class="breadcrumb-wrap">
                        <nav aria-label="breadcrumb">
                            <ul class="breadcrumb">
                                <li class="breadcrumb-item"><a href="{{route('home')}}"><i class="fa fa-home"></i></a></li>
                                <li class="breadcrumb-item"><a href="#">shop</a></li>
                                <li class="breadcrumb-item active" aria-current="page">{{ $product->collectLocalization('name') }}</li>
                            </ul>
                        </nav>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- breadcrumb area end -->

        <!-- page main wrapper start -->
        <div class="shop-main-wrapper section-padding pb-0">
            <div class="container">
                <div class="row">
                    <!-- product details wrapper start -->
                    <div class="col-lg-12 order-1 order-lg-2">
                        <!-- product details inner end -->
                        <div class="product-details-inner">
                            <div class="row">   
                                <div class="col-lg-5">
                                    <div class="product-large-slider">
      
                                      <div class="pro-large-img img-zoom">
                                        <img loading="lazy" src="{{ uploadedAsset($product->thumbnail_image) }}" 
                                          alt="{{ $product->collectLocalization('name') }}" 
                                          onerror="this.onerror=null;this.src='{{ asset('backend/assets/img/placeholder-thumb.png') }}';">
                                      </div>
      
                                      @if(!empty($galleryImages) || sizeof($galleryImages)>0)  
                                        @forelse ($galleryImages as $galleryImage)
                                          <div class="pro-large-img img-zoom">
                                            <img loading="lazy" src="{{ uploadedAsset($galleryImage) }}"  
                                              onerror="this.onerror=null;this.src='{{ asset('backend/assets/img/placeholder-thumb.png') }}';" 
                                              alt="{{ $product->collectLocalization('name') }}">
                                          </div>
                                        @empty
                                        @endforelse
                                      @endif
      
                                    </div>
                               
                                    <div class="pro-nav slick-row-10 slick-arrow-style">
                                      <div class="pro-nav-thumb">
                                        <img loading="lazy" src="{{ uploadedAsset($product->thumbnail_image) }}" 
                                          alt="{{ $product->collectLocalization('name') }}" 
                                          onerror="this.onerror=null;this.src='{{ asset('backend/assets/img/placeholder-thumb.png') }}';">
                                      </div>
      
                                      @if(!empty($galleryImages) || sizeof($galleryImages)>0)  
                                        @forelse ($galleryImages as $galleryImage)
                                        <div class="pro-nav-thumb">
                                          <img loading="lazy" src="{{ uploadedAsset($galleryImage) }}"  
                                            onerror="this.onerror=null;this.src='{{ asset('backend/assets/img/placeholder-thumb.png') }}';" 
                                            alt="{{ $product->collectLocalization('name') }}">
                                        </div>
                                        @empty
                                        @endforelse
                                      @endif
                                    </div>
                                </div>
                                <div class="col-lg-7">
                                  <form action="{{route('carts.store')}}" method="post" class="quick_view_form">
                                    @csrf
                                    <input type="hidden" value="{{$product->id}}" name="product_id" class="product_id">

                                    <div class="product-details-des">
                                        <div class="manufacturer-name">
                                            <a href="#">{{ $product->brand->name ?? '' }}</a>
                                        </div>
                                        <h3 class="product-name">{{ $product->collectLocalization('name') }} </h3>

                                        
                                         
                                        <div class="price-box product-price_pd_{{$product->id}}">

                                            @if (productBasePrice($product) == discountedProductBasePrice($product))
                                            @if (productBasePrice($product) == productMaxPrice($product))
                                                <span class="price-regular">{{ formatPrice(productBasePrice($product)) }}</span>
                                            @else
                                                <span class="price-regular">{{ formatPrice(productBasePrice($product)) }}</span>
                                            @endif
                                        @else
                                            @if (discountedProductBasePrice($product) == discountedProductMaxPrice($product))
                                                <span class="price-regular">{{ formatPrice(discountedProductBasePrice($product)) }}</span>
                                            @else
                                                <span class="price-regular">{{ formatPrice(discountedProductBasePrice($product)) }}</span>
                                            @endif
                                            
                                            @if (!isset($onlyPrice) || $onlyPrice == false)
                                                @if (productBasePrice($product) == productMaxPrice($product))
                                                    <span
                                                        class="price-old {{ isset($br) ? '' : 'ms-1' }}">{{ formatPrice(productBasePrice($product)) }}</span>
                                                @else
                                                    <span
                                                        class="price-old {{ isset($br) ? '' : 'ms-1' }}">{{ formatPrice(productBasePrice($product)) }}</span>
                                                @endif
                                            @endif
                                        @endif

                                        </div> 
                                        <p class="pro-desc">{{ $product->collectLocalization('short_description') }}</p>
                                        @if (count(generateVariationOptions($product->variation_combinations)) > 0)
                                                @foreach (generateVariationOptions($product->variation_combinations) as $variation)
                                                <input type="hidden" name="variation_id[]" value="{{ $variation['id'] }}" class="variation-for-cart">
                                                <div class="pro-size">
                                                    <h6 class="option-title">{{ $variation['name'] }} :</h6>
                                                    <select class="nice-select attribute_dropdown" data-id="{{$variation['id']}}"  name="variation_value_for_variation_{{ $variation['id'] }}" >
                                                        @foreach ($variation['values'] as $value)
                                                            <option @if ($loop->first) selected @endif  data-id="{{$variation['id']}}:{{ $value['id']}}/"   value="{{ $value['id'] }}" 
                                                                 title="{{ $value['name'] }}">
                                                                {{ $value['name'] }}
                                                            </option>
                                                        @endforeach
                                                    </select>
                                                </div>
                                                @endforeach
                                            @endif
                                        <div class="quantity-cart-box d-flex align-items-center">
                                            <h6 class="option-title">qty:</h6>
                                            <div class="quantity">
                                                <div class="pro-qty">
                                                    <input type="text" class="qty_val" data-min_val="{{$product->minimum_quantity ?? 1}}" data-product="{{$product->increment_unit}}" name="quantity" value="{{$product->minimum_quantity}}">
                                                </div>
                                            </div>
                                            <div class="action_link">
                                                <input type="hidden" name="_token" value="{{ csrf_token() }}">
                                            
                                                <input type="hidden" name="product_variation_id" value="{{ $product->variations[0]->id }}"> 
                                                <input type="hidden" name="product_id" value="{{$product->id}}"/> 
                                                <button class="btn btn-cart2 direct-add-to-cart-btn" type="submit">add to cart</button> 
                                        
                                            </div>  
                                        </div>
                                        
                                        <div class="useful-links">
                                            
                                            <a href="javascript::void(0)" onclick="addToWishlist({{ $product->id }})" data-bs-toggle="tooltip" title="Wishlist"><i
                                                    class="pe-7s-like"></i>wishlist</a>
                                        </div>
                                        <div class="like-icon">
                                            <a class="facebook" href="javascript:void(0);" onclick="shareOnFacebook('{{ url()->current() }}')"><i class="fa fa-facebook"></i>facebook</a>
                                            <a class="twitter" href="javascript:void(0);" onclick="shareOnTwitter('{{ url()->current() }}')"><i class="fa fa-twitter"></i>twitter</a> 
                                        </div>
                                    </div>

                                  </form>  
                                </div>
                            </div>
                        </div>
                        <!-- product details inner end -->

                        <!-- product details reviews start -->
                        <div class="product-details-reviews section-padding pb-0">
                            <div class="row">
                                <div class="col-lg-12">
                                    <div class="product-review-info">
                                        <ul class="nav review-tab">
                                            <li>
                                                <a class="active" data-bs-toggle="tab" href="#tab_one">description</a>
                                            </li> 
                                            <li>
                                                <a data-bs-toggle="tab" href="#tab_three">reviews ({{$productReview->count()}})</a>
                                            </li>
                                        </ul>
                                        <div class="tab-content reviews-tab">
                                            <div class="tab-pane fade show active" id="tab_one">
                                                <div class="tab-one">
                                                    <p>{!! $product->collectLocalization('description') !!}</p>
                                                </div>
                                            </div>
                                            {{-- <div class="tab-pane fade" id="tab_two">
                                                <table class="table table-bordered">
                                                    <tbody>
                                                        <tr>
                                                            <td>color</td>
                                                            <td>black, blue, red</td>
                                                        </tr>
                                                        <tr>
                                                            <td>size</td>
                                                            <td>L, M, S</td>
                                                        </tr>
                                                    </tbody>
                                                </table>
                                            </div> --}}
                                            <div class="tab-pane fade" id="tab_three">  
                                                    @if(!empty($productReview))
                                                        @foreach ($productReview as $review) 
                                                            <div class="total-reviews"> 
                                                                <div class="rev-avatar">
                                                                    <img src="{{asset('assets/img/about/avatar.jpg')}}" alt="">
                                                                </div>
                                                                <div class="review-box">
                                                                    <div class="ratings">
                                                                        @for($i=1; $i<=$review->rating; $i++)
                                                                            <span><i class="fa fa-star"></i></span> 
                                                                        @endfor
                                                                    </div>
                                                                    <div class="post-author">
                                                                        <p><span>{{$review->user->name ?? ''}} -</span> {{ $review->created_at->format('d M, Y') }} </p>
                                                                    </div>
                                                                    <p>{{$review->review_text}}</p>
                                                                </div>
                                                            </div>
                                                        @endforeach
                                                    @endif
                                                    
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <!-- product details reviews end -->
                    </div>
                    <!-- product details wrapper end -->
                </div>
            </div>
        </div>
        <!-- page main wrapper end -->

        <!-- related products area start -->
        @if(!empty($relatedProducts) && sizeof($relatedProducts)>0)
        <section class="related-products section-padding">
            <div class="container">
                <div class="row">
                    <div class="col-12">
                        <!-- section title start -->
                        <div class="section-title text-center">
                            <h2 class="title">Related Products</h2>
                            <p class="sub-title">Add related products to weekly lineup</p>
                        </div>
                        <!-- section title start -->
                    </div>
                </div>
                <div class="row">
                    <div class="col-12">
                        <div class="product-carousel-4 slick-row-10 slick-arrow-style">
                             
                            @if(!empty($relatedProducts))
                                @foreach ($relatedProducts as $product)
                                        @php
                                            $galleryImages = !empty($product->gallery_images) ? explode(',', $product->gallery_images) : [];
                                            $discountPercentage = discountPercentage($product);
                                            $givenDateString = $product->created_at;
                                            $givenDate = new DateTime($givenDateString);
                                            $currentDate = new DateTime();
                                            $dateInterval = $currentDate->diff($givenDate);
                                            $daysDiff=$dateInterval->format('%a');
                                        @endphp 
                                    <!-- product item start -->
                                    <div class="product-item">
                                        <figure class="product-thumb">
                                            <a href="{{ route('products.show', $product->slug) }}">
                                                <img class="pri-img" src="{{ uploadedAsset($product->thumbnail_image) }}" alt="{{ $product->collectLocalization('name') }}" 
                                                onerror="this.onerror=null;this.src='{{ asset('backend/assets/img/placeholder-thumb.png') }}';">
                                            </a>
                                            <div class="product-badge">
                                                @if($daysDiff<7)
                                                <div class="product-label new">
                                                    <span>new</span>
                                                </div>
                                                @endif
                                                @if ($discountPercentage > 0)
                                                <div class="product-label discount">
                                                    <span>{{ discountPercentage($product) }}% off</span>
                                                </div>
                                                @endif
                                            </div>
                                            <div class="button-group">
                                                <a href="javascript:void(0);" data-bs-toggle="tooltip" data-bs-placement="left" title="" data-bs-original-title="Add to wishlist" onclick="addToWishlist({{ $product->id }})" aria-label="Add to wishlist" tabindex="-1"><i class="pe-7s-like"></i></a>
                                                
                                                <a href="javascript:void(0)" onclick="showProductDetailsModal({{ $product->id }})">
                                                    <span data-bs-toggle="tooltip" data-bs-placement="left" title="Quick View">
                                                        <i class="pe-7s-search"></i>
                                                    </span>
                                                </a>


                                            </div>
                                           
                                        </figure>
                                        <div class="product-caption text-center"> 
                                            <h6 class="product-name">
                                                <a href="{{ route('products.show', $product->slug) }}">{{ $product->collectLocalization('name') }}</a>
                                            </h6>
                                        
                                            <div class="price-box">
                                                @if (productBasePrice($product) == discountedProductBasePrice($product))
                                                    @if (productBasePrice($product) == productMaxPrice($product))
                                                        <span class="price-regular">{{ formatPrice(productBasePrice($product)) }}</span>
                                                    @else
                                                        <span class="price-regular">{{ formatPrice(productBasePrice($product)) }}</span>
                                                    @endif
                                                @else
                                                    @if (discountedProductBasePrice($product) == discountedProductMaxPrice($product))
                                                        <span class="price-regular">{{ formatPrice(discountedProductBasePrice($product)) }}</span>
                                                    @else
                                                        <span class="price-regular">{{ formatPrice(discountedProductBasePrice($product)) }}</span>
                                                
                                                    @endif
                                                    
                                                    @if (!isset($onlyPrice) || $onlyPrice == false)
                                                        @if (productBasePrice($product) == productMaxPrice($product))
                                                            <span class="price-old {{ isset($br) ? '' : 'ms-1' }}">{{ formatPrice(productBasePrice($product)) }}</span>
                                                        @else
                                                            <span class="price-old {{ isset($br) ? '' : 'ms-1' }}">{{ formatPrice(productBasePrice($product)) }}</span>
                                                        @endif
                                                    @endif
                                                @endif
                                            </div>
                                        </div>
                                    </div>
                                    <!-- product item end -->

                                @endforeach
                            @endif
 
                        </div>
                    </div>
                </div> 
               
            </div>
        </section>
        @endif
        <!-- related products area end -->
    </main>
  <!-- review modal start -->
   <div class="modal fade" id="reviewModal" tabindex="-1" aria-labelledby="reviewModalLabel" aria-hidden="true">
    <div class="modal-dialog">
      <div class="modal-content">
        <div class="modal-header">
          <h5 class="modal-title" id="reviewModalLabel">Write Your Review</h5>
          <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
        </div>
        <div class="modal-body">
              <form action="{{route('review.store')}}" method="POST" class="review-form">
                    @csrf
                <input type="hidden" name="product_id" value="{{$product->id}}">
                <div class="form-group row">
                    <div class="col">
                        <label class="col-form-label"><span class="text-danger">*</span>
                            Your Review</label>
                        <textarea class="form-control"  required name="review_text"></textarea>
                        <div class="help-block pt-10"><span class="text-danger">Note:</span>
                            HTML is not translated!
                        </div>
                    </div>
                </div>
                <div class="form-group row">
                    <div class="col">
                        <label class="col-form-label"><span class="text-danger">*</span>
                            Rating</label>
                        &nbsp;&nbsp;&nbsp; Bad&nbsp;
                        <input type="radio" class="form-check-input" value="1" name="rating" required>
                        &nbsp;
                        <input type="radio" class="form-check-input" value="2" name="rating" required>
                        &nbsp;
                        <input type="radio" class="form-check-input" value="3" name="rating" required>
                        &nbsp;
                        <input type="radio" class="form-check-input" value="4" name="rating" required>
                        &nbsp;
                        <input type="radio" class="form-check-input" value="5" name="rating" required>
                        &nbsp;Good
                    </div>
                </div>
                <div class="buttons">
                    <button class="btn btn-sqr" type="submit" id="product_review_form_btn">Continue</button>
                </div>
            </form> <!-- end of review-form -->
        </div>
      </div>
    </div>
  </div>


  @push('scripts') 
        <script>

        
        $(document).ready(function () {
            $('#reviewModal').click(function() { 
                $("#review").modal('show');
            });
        });

        function shareOnTwitter(url) {
            window.open('https://twitter.com/intent/tweet?url=' + encodeURIComponent(url), '_blank');
        }   

        function shareOnFacebook(url) {
            window.open('https://www.facebook.com/sharer/sharer.php?u=' + encodeURIComponent(url), '_blank');
        }


        function directAddToCartFormSubmit($this) {
            // add to cart here
            let parent = $($this).closest('.direct-add-to-cart-form');

            parent.find('.direct-add-to-cart-btn').prop('disabled', true);

            let text = parent.find('.add-to-cart-text').html();
            parent.find('.add-to-cart-text').html();


            let data = parent.serializeArray();
            $.ajax({
                type: "POST",
                url: '{{ route('carts.store') }}',
                data: data,
                success: function(data) { 
                     flash(localize('Product add to cart !!'));
                    setTimeout(function () {
                        location.reload();
                    }, 3000);
                }
            });
        }

     $(document).ready(function () {
        $('#qty_val').blur(function() { 
            var qty = $(this).val();
            $("#quantity").val(qty);                 
        });
    });
     
    </script>
  @endpush
</x-frontend.app-layout>